@@ -10,11 +10,18 @@ struct ConvertedJson {
     label: Option<String>,
     secret: String,
     issuer: Option<String>,
+    #[serde(rename="type")]
+    type_: String,
+    algorithm: String,
     digits: u64,
+    counter: u64
 }
 
 pub fn import(filepath: &str) -> Result<Vec<OTPElement>, String> {
-    let file_to_import_contents = read_to_string(filepath).unwrap();
+    let file_to_import_contents = match read_to_string(filepath) {
+        Ok(result) => result,
+        Err(e) => return Err(format!("Error during file reading: {:?}",e)),
+    };
     let result: Result<Vec<ConvertedJson>, serde_json::Error> = serde_json::from_str(&file_to_import_contents);
     let vector: Vec<ConvertedJson>;
 
@@ -25,22 +32,19 @@ pub fn import(filepath: &str) -> Result<Vec<OTPElement>, String> {
 
     let mut elements: Vec<OTPElement> = Vec::new();
 
-    for i in 0..vector.len() {
-        let secret = vector[i].secret.to_owned();
-        let issuer = vector[i].issuer.to_owned().unwrap_or_default();
-        let label = vector[i].label.to_owned().unwrap_or_default();
-        let digits = vector[i].digits;
+    for element in vector {
         elements.push(OTPElement::new(
-            secret,
-            issuer,
-            label,
-            digits,
-            String::from("TOTP"),
-            String::from("SHA1"),
+            element.secret,
+            element.issuer.unwrap_or_default(),
+            element.label.unwrap_or_default(),
+            element.digits,
+            element.type_,
+            element.algorithm,
             String::from(""),
             0,
             0,
             30,
+            element.counter,
             vec![]))
     }
     Ok(elements)
