@@ -1,7 +1,7 @@
 use tui::widgets::TableState;
 
 use crate::otp::otp_element::OTPElement;
-use crate::otp::otp_helper::get_good_otp_code;
+use crate::otp::otp_helper::get_otp_code;
 
 pub struct StatefulTable {
     pub(crate) state: TableState,
@@ -9,16 +9,12 @@ pub struct StatefulTable {
 }
 
 impl StatefulTable {
-    pub fn new(elements: &Vec<OTPElement>) -> StatefulTable {
+    pub fn new(elements: &[OTPElement]) -> StatefulTable {
         let mut table = StatefulTable {
             state: TableState::default(),
             items: vec![],
         };
-        let mut i = 0;
-        for element in elements {
-            table.items.push(vec![(i + 1).to_string(), element.issuer(), element.label(), get_good_otp_code(element)]);
-            i += 1;
-        }
+        fill_table(&mut table,elements);
         table
     }
     pub fn next(&mut self) {
@@ -48,4 +44,19 @@ impl StatefulTable {
         };
         self.state.select(Some(i));
     }
+}
+
+pub fn fill_table(table: &mut StatefulTable, elements: &[OTPElement]) {
+    for (i, element) in elements.iter().enumerate() {
+        let label = match element.type_().as_str() {
+            "HOTP" => {
+                match element.counter() {
+                    Some(result) => element.label() + (format!(" ({} counter)",result).as_str()),
+                    None => element.label(),
+                }
+            },
+            _ => element.label(),
+        };
+        table.items.push(vec![(i + 1).to_string(), element.issuer(), label , get_otp_code(element).unwrap()]);
+    }
 }
\ No newline at end of file
